@@ -5,7 +5,7 @@
 # Author    : Chris Jones
 # Email     : crj341@student.bham.ac.uk
 # Date      : 26/06/2020
-# Version   : 0.1.20
+# Version   : 0.1.21
 
 import  numpy                   as      np
 import  plotly.graph_objects    as      go
@@ -551,8 +551,8 @@ class AFM:
             _approach = self.approach[:,i]
             _retract = self.retract[:,i]
                 
-            tip_approach = _z[0:self.samps_line] + self.spr_const * _approach
-            tip_retract = _z[(self.samps_line + 1):(self.samps_line * 2)] + self.spr_const * _retract
+            tip_approach = _z[:self.samps_line] + self.spr_const * _approach
+            tip_retract = _z[self.samps_line:] + self.spr_const * _retract
 
             tip_position = np.concatenate((tip_approach, tip_retract), axis = 0)
 
@@ -567,8 +567,8 @@ class AFM:
         plot must be given as an input <.plot_adjusted(n)>
         '''
         fig = go.Figure()
-        fig.add_trace(go.Scatter(y = self.approach[:,curve_number], x = self.z_position[:,curve_number][0:self.samps_line], mode='lines', name = 'Approach curve'))
-        fig.add_trace(go.Scatter(y = self.retract[:,curve_number], x = self.z_position[:,curve_number][(self.samps_line + 1):(self.samps_line * 2)], mode='lines', name = 'Retract curve'))
+        fig.add_trace(go.Scatter(y = self.approach[:,curve_number], x = self.z_position[:,curve_number][:self.samps_line], mode='lines', name = 'Approach curve'))
+        fig.add_trace(go.Scatter(y = self.retract[:,curve_number], x = self.z_position[:,curve_number][self.samps_line:], mode='lines', name = 'Retract curve'))
         fig.update_layout(
             yaxis_title_text='Force (nN)',
             xaxis_title_text='Tip separation (nm)',
@@ -589,14 +589,14 @@ class AFM:
                         visible=False,
                         name= 'Approach ' + str(step),
                         y = self.approach[:, step],
-                        x = self.z_position[:, step][0:self.samps_line]
+                        x = self.z_position[:, step][:self.samps_line]
                     ))
 
             trace_2.append(go.Scatter(
                         visible=False,
                         name= 'Retract ' + str(step),
                         y = self.retract[:, step],
-                        x = self.z_position[:, step][(self.samps_line + 1):(self.samps_line * 2)]
+                        x = self.z_position[:, step][self.samps_line:]
                     ))
 
         fig = go.Figure(data = trace_1 + trace_2)
